@@ -19,7 +19,7 @@ use Term::ANSIColor;
 use Log::Fast;
 use Time::HiRes qw(time);
 use File::Basename;
-use Data::Dumper;
+use Best qw(Data::Dumper::Simple Data::Dumper);
 use Config;
 use threads;
 
@@ -27,7 +27,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.16;
+    our $VERSION = 1.17;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -468,9 +468,7 @@ sub debug {
         $level = uc($msgs);                                 # It tosses the legacy __LINE__ argument
         $msgs  = shift;
     }
-    $level = 'ERR'  if ($level eq 'ERROR');                 # This allows the programmer to use either
-    $level = 'WARN' if ($level eq 'WARNING');
-    $level = 'INFO' if ($level eq 'INFORMATION');
+    $level =~ s/(OR|ING|RMATION)$//; # Strip off the excess
 
     # A much quicker bypass when the log level is below what is needed
     return if ($LevelLogic{$self->{'LOGLEVEL'}} < $LevelLogic{$level});
@@ -564,7 +562,7 @@ sub debug {
     $self->{$level . '_LASTSTAMP'} = time;
 } ## end sub debug
 
-sub _send_to_logger {      # This actually simplifies the previous object ... seriously
+sub _send_to_logger {      # This actually simplifies the previous method ... seriously
     my $self       = shift;
     my $level      = shift;
     my $padding    = shift;
@@ -667,7 +665,7 @@ sub WARNING {
     $self->debug('WARN', @_);
 }
 
-=head2 B<NOTICE>
+=head2 B<NOTICE> or B<ATTENTION>
 
 If the loglevel is NOTICE or above, then these notices are logged.
 
@@ -685,6 +683,11 @@ sub NOTICE {
     $self->debug('NOTICE', @_);
 }
 
+sub ATTENTION {
+    my $self = shift;
+    $self->debug('NOTICE'. @_);
+}
+
 =head2 B<INFO> or B<INFORMATION>
 
 If the loglevel is INFO (or VERBOSE) or above, then these information messages are displayed.
@@ -780,7 +783,7 @@ This program is free software; you can redistribute it and/or modify it under th
 
 =head1 B<VERSION>
 
-Version 1.15    (October 19, 2016)
+Version 1.17    (November 10, 2016)
 
 =head1 B<BUGS>
 
